SemanticLlmCache

Struct SemanticLlmCache 

pub struct SemanticLlmCache {
    pub embedder: Arc<dyn Embedder>,
    pub threshold: f32,
    /* private fields */
}

Fields

embedder: Arc<dyn Embedder>threshold: f32

Implementations

Source

impl SemanticLlmCache

pub fn new(embedder: Arc<dyn Embedder>, threshold: f32) -> Self

pub fn len(&self) -> usize

pub async fn get_by_text(&self, text: &str) -> Result<Option<CachedTurn>>

Variant get keyed by the prompt text rather than the hash-based CacheKey. Useful when the caller has the original prompt available.

pub async fn put_with_text( &self, text: impl Into<String>, key: CacheKey, value: CachedTurn, ) -> Result<()>